@@ -25,10 +25,10 @@ class RunApplicationPlugin : public Plugin {
     // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.virtualdesktopswitch")
 
 public:
-    explicit RunApplicationPlugin(QObject *parent = Q_NULLPTR, const QVariantList &args = QVariantList());
-    ~RunApplicationPlugin() Q_DECL_OVERRIDE;
+    explicit RunApplicationPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    ~RunApplicationPlugin() override;
 
-    bool init(QHash<QString, QObject *> &modules) Q_DECL_OVERRIDE;
+    bool init(QHash<QString, QObject *> &modules) override;
 
 private Q_SLOTS:
     void currentActivityChanged(const QString &activity);
